# -*- coding: utf-8 -*-
import scrapy, re
from datetime import datetime, timedelta, tzinfo
from desdeElBalcon.items import NoticiasItem

"""
MEDIO:
Desde el Balcon, Yucatan
USO:
scrapy crawl noticias --nolog -s filename=2017-03-22.json -a year=2017 -a month=3 -a day=22
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class UTC(tzinfo):
    """clase para el 'time zone' (zona horaria)"""

    def utcoffset(self, dt):
        # zona horaria para yucatan (centro de mexico): utc-6
        return timedelta(hours=-6)

    def tzname(self, dt):
        # nombre de la zona horaria
        return 'UTC-6'


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        self.tz = UTC()
        self.year = getattr(self, 'year', None)
        self.month = getattr(self, 'month', None)
        self.day = getattr(self, 'day', None)
        self.baseURL='http://www.desdeelbalcon.com/'+self.year+'/'+self.month+'/'+self.day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        pagination = response.xpath('//*[@class="pagination"]/a[@class="page-numbers"]/@href').extract()
        if len(pagination) > 0:
            pagination = pagination[-1].strip('/')
            pages = int(pagination[pagination.rfind('/')+1:])

            for page in range(1, pages):
                yield scrapy.Request(url=self.baseURL+"/page/"+str(page+1), callback=self.parse_page)



    def parse_page(self, response):
        item = NoticiasItem()

        for post in response.xpath('//ul[@class="archivepost"]/li'):
            # item['date'] = self.year+'-'+self.month.zfill(2)+'-'+self.day.zfill(2)
            item['date'] = datetime(int(self.year),int(self.month),int(self.day),tzinfo=self.tz).isoformat('T')
            item['topic'] = post.xpath('./p/a/text()').extract()
            request = scrapy.Request(url=post.xpath('./h2/a/@href').extract_first(), callback=self.parse_item)
            request.meta['item'] = item

            yield request


    def parse_item(self, response):
        text = ''
        item = response.meta['item']

        item['title'] = response.xpath('//h1[@class="post entry-title"]/a/text()').extract_first()

        for paragraph in response.xpath('//div[@itemprop="text"]/p').extract():
            text += remove_tags(paragraph) + '\n'
        item['text'] = text

        item['url'] = response.url

        # print item['title']
        yield item

