# -*- coding: utf-8 -*-
import scrapy, re
from edoMexDia.items import NoticiasItem
from datetime import datetime, timedelta, tzinfo

"""
MEDIO:
EDOMEX al Día, Estado de México
USO:
scrapy crawl noticias --nolog -s filename=2018-01-30.json -a year=2018 -a month=1 -a day=30
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class UTC(tzinfo):
    """clase para el 'time zone' (zona horaria)"""

    def utcoffset(self, dt):
        # zona horaria para estado de méxico: utc-6
        return timedelta(hours=-6)

    def tzname(self, dt):
        # nombre de la zona horaria
        return 'UTC-6'


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        self.tz = UTC()
        self.year = getattr(self, "year", None)
        self.month = getattr(self, "month", None)
        self.day = getattr(self, "day", None)
        self.date_parser = {'january': 1,   'february': 2, 'march': 3,     'april': 4,
                            'may': 5,       'june': 6,     'july': 7,      'august': 8,
                            'september': 9, 'october': 10, 'november': 11, 'december': 12}

        self.baseURL = "http://www.edomexaldia.com.mx/" + self.year + "/" + self.month.zfill(2) + "/" + self.day.zfill(2)

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        lastPage = response.xpath('//div[@class="numbered-pagination"]/a[@class="pagi-last"]/@href').extract_first()
        if lastPage is None:
            lastPage = response.xpath('//div[@class="numbered-pagination"]/a/@href').extract()[-1]
        if lastPage is not None and lastPage != '':
            lastPage = lastPage.strip('/')
            lastPage = int(lastPage[lastPage.rfind('/')+1:])

            for page in range(1, lastPage):
                yield scrapy.Request(url=self.baseURL + "/page/" + str(page+1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.xpath('//div[@id="main"]/div/h2[@class="entry_title"]/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)

        nextPage = response.xpath('//div[@class="numbered-pagination"]/a[@class="pagi-next"]/@href').extract_first()
        if nextPage is not None and nextPage != '':
            yield scrapy.Request(url=nextPage, callback=self.parse)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        try:
            d = remove_tags(response.xpath('//span[@class="post_author_create"]').extract_first())
            d = d.replace("el ", '').replace(",", '').replace(".", '').split()
            dat = datetime(int(d[2]), self.date_parser[d[1].lower()], int(d[0]), tzinfo=self.tz).isoformat("T")
        except:
            dat = datetime(int(self.year), int(self.month), int(self.day), tzinfo=self.tz).isoformat("T")
        item['date'] = dat

        item['title'] = remove_tags(response.xpath('//div[@id="main"]/div/h1').extract_first()).strip()
        item['topic'] = None

        author = response.xpath('//span[@class="post_author_author"]').extract_first()
        if author is not None and author != '':
            author = remove_tags(author).strip()
            author = author.replace(" Publicado:", '')
            item['author'] = author

        for p in response.xpath('//div[@id="main"]/div/p').extract():
            text += remove_tags(p) + "\n"
        item['text'] = text.strip()

        item['url'] = response.url

        yield item
