# -*- coding: utf-8 -*-
import scrapy, re, json
from expresoChiapas.items import NoticiasItem
from datetime import datetime, timedelta, tzinfo

"""
MEDIO:
Expreso Chiapas
USO:
scrapy crawl noticias --nolog -s filename=2018-01-30.json -a year=2018 -a month=1 -a day=30
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)

CLEAN_RE = re.compile(r'\A.*?\sl\s')

class UTC(tzinfo):
    """clase para el 'time zone' (zona horaria)"""

    def utcoffset(self, dt):
        # zona horaria para hidalgo (centro de mexico): utc-6
        return timedelta(hours=-6)

    def tzname(self, dt):
        # nombre de la zona horaria
        return 'UTC-6'


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        self.tz = UTC()
        self.year = getattr(self, "year", None)
        self.month = getattr(self, "month", None)
        self.day = getattr(self, "day", None)

        self.baseURL = "http://expresochiapas.com/noticias/" + self.year + "/" + self.month.zfill(2) + "/" + self.day.zfill(2)

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        for link in response.xpath('//div[@class="mag-box-container"]/ul/li/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)

        nextPage = response.xpath('//div[@class="pages-nav"]/div').css('span.last-page').xpath('./a/@href').extract_first()
        if nextPage is not None and nextPage != '':
            yield scrapy.Request(url=nextPage, callback=self.parse)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        "La fecha obtenida ya incluye formato y zona horaria"
        try:
            res = response.xpath('//article[@id="the-post"]/script[@type="application/ld+json"]').extract_first()
            if res is not None:
                res = remove_tags(res)
                jsonObj = json.loads(res)
                dat = jsonObj['datePublished']
        except:
            dat = datetime(int(self.year), int(self.month), int(self.day), tzinfo=self.tz).isoformat("T")
        item['date'] = dat

        item['title'] = remove_tags(response.xpath('//div[@class="entry-header"]/h1').extract_first()).strip()

        topic = response.xpath('//div[@class="entry-header"]/h5/a').extract_first()
        if topic is not None:
            item['topic'] = remove_tags(topic)

        for p in response.xpath('//div[@class="entry-content entry clearfix"]/p').extract():
            text += remove_tags(p) + "\n"
        text = text.strip()
        item['text'] = CLEAN_RE.sub('', text)

        item['url'] = response.url

        yield item
