# -*- coding: utf-8 -*-
import scrapy, re
from sanPedroSun.items import NoticiasItem

"""
MEDIO:
The San Pedro Sun, Belice
USO:
scrapy crawl noticias --nolog -s filename=2018-02-23.json -a year=2018 -a month=2 -a day=23
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


DATE_RE1 = re.compile(r'(-|- )?([A-Z][a-z]+, ?)?[A-Z][a-z]+( \d{1,2})?, \d{4}( -|\n)? ?[A-Z]')
DATE_RE2 = re.compile(r', [a-zA-Z]+ \d{1,2} -( -)?')
AUTH_RE = re.compile(r'\n(- )?By.+\n')


class importantData(scrapy.Item):
    page = scrapy.Field()


class QuotesSpider(scrapy.Spider):
    name = "noticias"
    globalSet = set()

    def start_requests(self):
        year = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day = getattr(self, "day", None)

        self.baseURL = "https://www.sanpedrosun.com/wp-content/themes/sunbase/GetResults.php?year=" + year + "&monthnum=" + month + "&day=" + day + "&posts_per_page=8&n_view=standard&n_style=list"
        # self.baseURL = "https://www.sanpedrosun.com/wp-content/themes/sunbase/GetResults.php?year=" + year + "&monthnum=" + month + "&posts_per_page=8&n_view=standard&n_style=list"

        searchData = importantData()
        searchData['page'] = 0

        request = scrapy.Request(url=self.baseURL, callback=self.parse)
        request.meta['item'] = searchData
        yield request


    def parse(self, response):
        localSet = set(response.css('div.entry').xpath('./h2/a/@href').extract())
        resultSet = localSet - self.globalSet

        if len(resultSet) > 0:
            searchData = response.meta['item']

            for link in resultSet:
                self.globalSet.add(link)
                yield scrapy.Request(url=link, callback=self.parse_item)

            searchData['page'] += 1
            page = searchData['page']

            request = scrapy.Request(url=response.url + "&n_more=" + str(page), callback=self.parse)
            request.meta['item'] = searchData
            yield request


    def parse_page(self, response):
        for link in response.css('div.td-ss-main-content').css('div.item-details').xpath('./h3/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        "La fecha obtenida ya incluye formato y zona horaria"
        item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
        item['title'] = remove_tags(response.xpath('//div[@class="post"]/h1').extract_first()).strip()

        try:
            topic = response.xpath('//div[@class="breadcrumb"]/p/a/text()').extract()[-1]
        except:
            try:
                topic = response.xpath('//ul[@class="td-category"]/li/a/text()').extract_first()
            except:
                topic = None
        item['topic'] = topic

        for p in response.xpath('//div[@class="entry"]').css('p').extract():
            text += remove_tags(p) + "\n"

        text = text.strip()
        text = "\n" + text
        text = text.replace(u'\u2013', "-")
        text = text.replace(u'\u00a0', '')  ## Elimina 'no-break spaces'

        res = DATE_RE1.search(text)
        if res:
            m = res.group(0)[:-1]
            text = text[text.find(m) + len(m):].strip()
            text = "\n" + text

        res = DATE_RE2.search(text)
        if res:
            m = res.group(0)[:-1]
            text = text[text.find(m) + len(m):].strip()
            text = "\n" + text

        res = AUTH_RE.match(text)
        if res:
            m = res.group(0)
            text = text[text.find(m) + len(m):].strip()
            text = "\n" + text

        text = text.replace("Follow The San Pedro Sun News on Twitter, become a fan on Facebook. Stay updated via RSS", '')
        item['text'] = text.strip()

        item['url'] = response.url

        yield item
