# -*- coding: utf-8 -*-
import scrapy, re
from tiempoDigitalHn.items import NoticiasItem

"""
MEDIO:
Tiempo Digital, Honduras
USO:
scrapy crawl noticias --nolog -s filename=2018-02-23.json -a year=2018 -a month=2 -a day=23
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)

LOC_RE1 = re.compile(r'\n([A-Z]+ )+ ?[.-]')
LOC_RE2 = re.compile(r'\n.+?,? ?.+? ?(\. ?-|\.|-) ?[A-Z]')
SOURCE_RE = re.compile(r'\n ?Fuente:.+$')

class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day = getattr(self, "day", None)

        self.baseURL = "https://tiempo.hn/" + year + "/" + month.zfill(2) + "/" + day.zfill(2)

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        pagination = response.css('div.page-nav').xpath('./a/@href').extract()
        if len(pagination) > 0:
            try:
                pagination = pagination[-2]
            except:
                pagination = pagination[-1]
            pagination = pagination.strip('/')
            pages = int(pagination[pagination.rfind('/') + 1:])

            for page in range(1, pages):
                yield scrapy.Request(url=self.baseURL + '/page/' + str(page + 1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.css('div.td-ss-main-content').css('div.td_module_1').xpath('./h3/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        "La fecha obtenida ya incluye formato y zona horaria"
        item['date'] = response.xpath('//span[@class="td-post-date"]/time/@datetime').extract_first()
        item['title'] = remove_tags(response.xpath('//header[@class="td-post-title"]/h1').extract_first()).strip()

        try:
            topic = response.xpath('//ul[@class="td-category"]/li').extract()[-1]
            item['topic'] = remove_tags(topic)
        except:
            item['topic'] = None

        author = response.xpath('//div[@class="td-post-author-name"]/a').extract_first()
        if author is not None:
            item['author'] = remove_tags(author)

        for p in response.xpath('//div[@class="td-post-content"]').css('p').extract():
            text += remove_tags(p) + "\n"

        text = text.strip()
        text = "\n" + text
        text = text.replace(u'\u2013', "-")
        text = text.replace(u'\u00a0', '') ## Elimina 'no-break spaces'

        res = LOC_RE1.match(text)
        if res:
            m = res.group(0)[:-1]
            location = m.replace("-", '').strip()
            if len(location) <= 25:
                item['location'] = location
                text = text.replace(m, '').strip()
                text = "\n" + text

        res = LOC_RE2.match(text)
        if res:
            m = res.group(0)[:-1]
            location = m.replace("-", '').replace(".", '').strip()
            if len(location) <= 25:
                item['location'] = location
                text = text.replace(m, '').strip()
                text = "\n" + text

        res = SOURCE_RE.search(text)
        if res:
            m = res.group(0)
            text = text.replace(m, '').strip()
            text = "\n" + text

        item['text'] = text.strip()

        item['url'] = response.url

        yield item
