# -*- coding: utf-8 -*-
import scrapy, re
from laJornadaZac.items import NoticiasItem

"""
MEDIO:
La Jornada Zacatecas, Zac.
USO:
scrapy crawl noticias --nolog -s filename=2017-03-22.json -a year=2017 -a month=3 -a day=22
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, 'year', None)
        month = getattr(self, 'month', None)
        day = getattr(self, 'day', None)

        self.baseURL = "http://ljz.mx/" + year + "/" + month + "/" + day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        pagination = response.xpath('//div[@class="pagination"]/a/@href').extract()
        if len(pagination) > 0:
            pagination = pagination[-1].strip('/')
            pages = int(pagination[pagination.rfind('/')+1:])

            for page in range(1,pages):
                yield scrapy.Request(url=self.baseURL+'/page/'+str(page+1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.xpath('//h2[@class="cat-list-title"]/a/@href').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        d = response.xpath('//*[@class="entry-post-meta"]').css('time::attr(content)').extract_first()
        ## '-06:00' corresponde al UTC-6, zona horaria de zacatecas (centro de mexico)
        if d[-6:] != '-06:00':
            d = d[:-6] + '-06:00'
        item['date'] = d

        item['title'] = response.xpath('//h1[@class="entry-title"]/text()').extract_first()
        item['topic'] = response.xpath('//*[@class="entry-cat"]/a/text()').extract_first()

        content = response.xpath('//*[@class="entry-content clearfix"]/p').extract()
        if ( len(content) == 0 ):
            content = response.xpath('//*[@class="entry-content clearfix"]/div/p').extract()
            if ( len(content) == 0 ):
                content = response.xpath('//*[@class="entry-content clearfix"]/div').extract()
                if ( len(content) == 0 ):
                    content = response.xpath('//*[@class="entry-content clearfix"]/div/div/p').extract()

        for paragraph in content:
            text += remove_tags(paragraph) + '\n'
        item['text'] = text
        item['url'] = response.url
        # print item['title']
        yield item

