# -*- coding: utf-8 -*-
import scrapy, re
from noticieroLinea.items import NoticiasItem

"""
MEDIO:
Noticiero en Línea, Colima
USO:
scrapy crawl noticias --nolog -s filename=2018-01-03.json -a year=2018 -a month=1 -a day=3
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)

LOC_RE = re.compile(r'\A.+?(\d{1,2}[\s-][a-zA-Z]+[\s-]\d{4})?\s?\.\s?-\s?', re.S)
G_RE = re.compile(r'\s?-\s?')
E_RE = re.compile(r'\(Con informaci.*?\)\.?')

class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day = getattr(self, "day", None)

        self.baseURL = "http://www.elnoticieroenlinea.com/" + year + "/" + month.zfill(2) + "/" + day.zfill(2)

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        for link in response.xpath('//*[@id="main-content"]').css('h3').css('a::attr(href)').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)

        nextPage = response.xpath('//*[@class="pagination clearfix"]/a[@class="next page-numbers"]/@href').extract_first()
        if nextPage is not None and nextPage != '':
            yield scrapy.Request(url=nextPage, callback=self.parse)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        "La fecha obtenida ya incluye formato y zona horaria"
        item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
        item['title'] = remove_tags(response.xpath('//h1[@class="entry-title"]').extract_first()).strip()

        item['topic'] = response.xpath('//*[@class="entry-tags clearfix"]/a/text()').extract_first()

        author = response.xpath('//*[@class="entry-content clearfix"]/h5').extract_first()
        if author is not None and author != '': author = remove_tags(author)
        if author is not None and author != '': item['author'] = author

        # text = remove_tags(response.xpath('//*[@class="entry-content clearfix"]').extract_first()).strip()
        # if author is not None and author != '': text = text.replace(author, '')
        # item['text'] = text

        for p in response.xpath('//*[@class="entry-content clearfix"]/p').extract():
            p = remove_tags(p)
            p = p.lstrip().replace(u'\u2013', "-")
            result = LOC_RE.match(p)
            if result:
                item['location'] = G_RE.sub('', result.group(0))

            text += p + "\n"

        text = LOC_RE.sub('', text)
        text = E_RE.sub('', text)
        text = text.replace("\ncomentarios", '')
        text = text.replace("Foto: Archivo.", '')
        item['text'] = text.strip()

        item['url'] = response.url

        yield item
