# -*- coding: utf-8 -*-
import scrapy, re
from yucatanALaMano.items import NoticiasItem

"""
MEDIO:
Yucatán a la Mano, Yuc.
USO:
scrapy crawl noticias --nolog -s filename=2017-03-22.json -a year=2017 -a month=3 -a day=22
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, 'year', None)
        month = getattr(self, 'month', None)
        day = getattr(self, 'day', None)

        # self.baseURL = "http://www.yucatanalamano.com/" + year + "/" + month + "/" + day
        # self.baseURL = "http://yucatanalamano.com/" + year + "/" + month + "/" + day
        urlList = ["http://www.yucatanalamano.com/" + year + "/" + month + "/" + day,
                   "http://yucatanalamano.com/" + year + "/" + month + "/" + day]

        for url in urlList:
            yield scrapy.Request(url=url, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

        pagination = response.css('div.pagination').css('a::attr(href)').extract()
        if len(pagination) > 0:
            pagination = pagination[-1].strip('/')
            pages = int(pagination[pagination.rfind('/')+1:])

            for page in range(1, pages):
                yield scrapy.Request(url=response.url+"/page/"+str(page+1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.css('div.bp-head').css('h2').css('a::attr(href)').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''
        title = response.xpath('//div[@class="main-col"]/div[@itemprop="name"]/text()').extract_first()
        if title is None:
            title = response.xpath('//div[@class="main-col"]').css('h1').extract_first()
        if title is not None:
            item['title'] = remove_tags(title)
        else:
            item['title'] = title

        d = response.css('div.mom-post-meta').css('span').css('time::attr(datetime)').extract_first()
        ## '-06:00' corresponde al UTC-6, zona horaria de yucatan (centro de mexico)
        if d[-6:] != '-06:00':
            d = d[:-6] + '-06:00'
        item['date'] = d

        item['topic'] = response.css('div.breadcrumbs-plus').css('span').css('a::attr(title)').extract_first()

        for paragraph in response.css('div.entry-content').css('p').extract():
            text += remove_tags(paragraph) + '\n'
        item['text'] = text
        item['url'] = response.url

        # print item['title']
        yield item

