# -*- coding: utf-8 -*-
import scrapy, re, json
from elFinanciero.items import NoticiasItem
from datetime import datetime, timedelta, tzinfo

"""
MEDIO:
El Financiero, CDMX
USO:
scrapy crawl noticias --nolog -s filename=2017-12-20.json
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)


class UTC(tzinfo):
	"""clase para el 'time zone' (zona horaria)"""

	def utcoffset(self, dt):
		# zona horaria para hidalgo (centro de mexico): utc-6
		return timedelta(hours=-6)

	def tzname(self, dt):
		# nombre de la zona horaria
		return 'UTC-6'


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        self.tz = UTC()
        # self.date_parser = {'enero': 1,      'febrero': 2,  'marzo': 3,      'abril': 4,
        #                     'mayo': 5,       'junio': 6,    'julio': 7,      'agosto': 8,
        #                     'septiembre': 9, 'octubre': 10, 'noviembre': 11, 'diciembre': 12}

        self.baseURL = "http://www.elfinanciero.com.mx/rss"
        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        for link in response.xpath('//link/text()').extract()[1:]:
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        res = remove_tags(response.xpath('//script[@type="application/ld+json"]').extract_first())
        resDict = json.loads(res)
        dt = resDict['datePublished']
        d,t = dt.split()
        d = map(int, d.split("-"))
        t = map(int, t.split(":"))
        item['date'] = datetime(d[0], d[1], d[2], t[0], t[1], t[2], tzinfo=self.tz).isoformat("T")

        item['title'] = remove_tags(response.css('div.column').css('div.column').css('h1').extract_first()).strip()

        topic = response.xpath('//div[@class="section-line"]').extract_first()
        if topic is not None:
            item['topic'] = remove_tags(topic)
        else:
            item['topic'] = None

        author = response.xpath('//div[@class="note-author"]/a').extract_first()
        if author is not None:
            item['author'] = remove_tags(author)

        for p in response.css('div.content').css('p').extract():
            text += remove_tags(p) + '\n'
        item['text'] = text.strip()

        item['url'] = response.url

        # print item['title']
        yield item

